# phpMyAdmin SQL Dump
# version 2.5.4
# http://www.phpmyadmin.net
#
# Host: localhost
# Generation Time: Nov 17, 2003 at 02:35 AM
# Server version: 4.0.16
# PHP Version: 4.3.3
# 
# Database : `diogenes`
# 

#
# Dumping data for table `diogenes_logactions`
#

INSERT INTO diogenes_logactions VALUES (3, 'auth_ok', 'successful password authentication');
INSERT INTO diogenes_logactions VALUES (2, 'auth_logout', 'the user logged out');
INSERT INTO diogenes_logactions VALUES (4, 'auth_fail', 'password authentication failed');
INSERT INTO diogenes_logactions VALUES (5, 'page_create', 'the user created a new page');
INSERT INTO diogenes_logactions VALUES (6, 'page_delete', 'the user deleted a page');
INSERT INTO diogenes_logactions VALUES (7, 'rcs_commit', 'Commit to RCS');
INSERT INTO diogenes_logactions VALUES (8, 'rcs_delete', 'An RCS-managed file was deleted');
INSERT INTO diogenes_logactions VALUES (9, 'barrel_create', 'a new barrel was created');
INSERT INTO diogenes_logactions VALUES (10, 'barrel_delete', 'a complete barrel was deleted');
INSERT INTO diogenes_logactions VALUES (11, 'file_upload', 'a file was uploaded');
INSERT INTO diogenes_logactions VALUES (12, 'file_delete', 'a file was deleted');
INSERT INTO diogenes_logactions VALUES (13, 'barrel_options', 'the barrel options were updated');
INSERT INTO diogenes_logactions VALUES (14, 'barrel_plugins', 'the barrel plugins were modified');
INSERT INTO diogenes_logactions VALUES (15, 'page_props', 'the page properties were updated');
INSERT INTO diogenes_logactions VALUES (16, 'page_plugins', 'the page plugins were modified');
